==> jc-1.4.0.tar.gz: soot/jimple/toolkits/scalar/FastAvailableExpressions.h <==
// public class soot.jimple.toolkits.scalar.FastAvailableExpressions

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f54af833873ba1d6 soot_jimple_toolkits_scalar_FastAvailableExpressions

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_scalar_FastAvailableExpressions_H_
#define _JC_soot_jimple_toolkits_scalar_FastAvailableExpressions_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_SideEffectTester$object;
struct _jc_soot_Unit$object;
struct _jc_soot_util_Chain$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$sub_refs	_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$sub_refs;
typedef struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$sub_nonrefs	_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$refs	_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$refs;
typedef struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$nonrefs	_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$object	_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$object;

typedef const struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$vmethods	_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$vmethods;
typedef const struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$vtable	_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$vtable;
typedef const struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$vtype	_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$method$_init$c05c4de42765c9c4(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$object *, struct _jc_soot_Body$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$method$getAvailableEquivsAfter$23bc091b3b3f1974(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$object *, struct _jc_object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$method$getAvailableEquivsBefore$d914784ab85b8c69(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$object *, struct _jc_object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$method$getAvailablePairsAfter$93c4c3b5ccb95d8e(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$object *, struct _jc_object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$method$getAvailablePairsBefore$d7ab6b141c12ce5a(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$method_info$getAvailableEquivsAfter$23bc091b3b3f1974;
extern _jc_method _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$method_info$getAvailableEquivsBefore$d914784ab85b8c69;
extern _jc_method _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$method_info$getAvailablePairsAfter$93c4c3b5ccb95d8e;
extern _jc_method _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$method_info$getAvailablePairsBefore$d7ab6b141c12ce5a;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$vmethods {
	struct _jc_object	*(*getAvailableEquivsAfter$23bc091b3b3f1974)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$object *, struct _jc_object *);
	struct _jc_object	*(*getAvailableEquivsBefore$d914784ab85b8c69)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$object *, struct _jc_object *);
	struct _jc_object	*(*getAvailablePairsAfter$93c4c3b5ccb95d8e)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$object *, struct _jc_object *);
	struct _jc_object	*(*getAvailablePairsBefore$d7ab6b141c12ce5a)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$vmethods	soot_jimple_toolkits_scalar_FastAvailableExpressions;
};

// Vtype
struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$sub_refs {
	struct _jc_object	*unitToPairsAfter;
	struct _jc_object	*unitToPairsBefore;
	struct _jc_object	*unitToEquivsAfter;
	struct _jc_object	*unitToEquivsBefore;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$refs {
    _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$sub_refs	soot_jimple_toolkits_scalar_FastAvailableExpressions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$sub_nonrefs	soot_jimple_toolkits_scalar_FastAvailableExpressions;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$object {
	_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$vtype	*vtype;
	_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$vtype _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_scalar_FastAvailableExpressions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$class_object;

#endif	/* _JC_soot_jimple_toolkits_scalar_FastAvailableExpressions_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/scalar/FastAvailableExpressions.h <==
// public class soot.jimple.toolkits.scalar.FastAvailableExpressions

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f54af833873ba1d6 soot_jimple_toolkits_scalar_FastAvailableExpressions

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_scalar_FastAvailableExpressions_H_
#define _JC_soot_jimple_toolkits_scalar_FastAvailableExpressions_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_SideEffectTester$object;
struct _jc_soot_Unit$object;
struct _jc_soot_util_Chain$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$sub_refs	_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$sub_refs;
typedef struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$sub_nonrefs	_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$refs	_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$refs;
typedef struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$nonrefs	_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$object	_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$object;

typedef const struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$vmethods	_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$vmethods;
typedef const struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$vtable	_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$vtable;
typedef const struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$vtype	_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$method$_init$c05c4de42765c9c4(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$object *, struct _jc_soot_Body$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$method$getAvailableEquivsAfter$23bc091b3b3f1974(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$method$getAvailableEquivsBefore$d914784ab85b8c69(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$method$getAvailablePairsAfter$93c4c3b5ccb95d8e(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$method$getAvailablePairsBefore$d7ab6b141c12ce5a(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$method_info$getAvailableEquivsAfter$23bc091b3b3f1974;
extern _jc_method _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$method_info$getAvailableEquivsBefore$d914784ab85b8c69;
extern _jc_method _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$method_info$getAvailablePairsAfter$93c4c3b5ccb95d8e;
extern _jc_method _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$method_info$getAvailablePairsBefore$d7ab6b141c12ce5a;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$vmethods {
	struct _jc_object	*(*getAvailableEquivsAfter$23bc091b3b3f1974)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getAvailableEquivsBefore$d914784ab85b8c69)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getAvailablePairsAfter$93c4c3b5ccb95d8e)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getAvailablePairsBefore$d7ab6b141c12ce5a)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$vmethods	soot_jimple_toolkits_scalar_FastAvailableExpressions;
};

// Vtype
struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$sub_refs {
	struct _jc_object	*unitToPairsAfter;
	struct _jc_object	*unitToPairsBefore;
	struct _jc_object	*unitToEquivsAfter;
	struct _jc_object	*unitToEquivsBefore;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$refs {
    _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$sub_refs	soot_jimple_toolkits_scalar_FastAvailableExpressions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$sub_nonrefs	soot_jimple_toolkits_scalar_FastAvailableExpressions;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$object {
	_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$vtype	*vtype;
	_jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$vtype _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_scalar_FastAvailableExpressions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_scalar_FastAvailableExpressions$class_object;

#endif	/* _JC_soot_jimple_toolkits_scalar_FastAvailableExpressions_H_ */
